import { replication } from '@powersync/service-core';
import { ConnectionManagerFactory } from './ConnectionManagerFactory.js';
export interface WalStreamReplicationJobOptions extends replication.AbstractReplicationJobOptions {
    connectionFactory: ConnectionManagerFactory;
}
export declare class WalStreamReplicationJob extends replication.AbstractReplicationJob {
    private connectionFactory;
    private readonly connectionManager;
    constructor(options: WalStreamReplicationJobOptions);
    /**
     * Postgres on RDS writes performs a WAL checkpoint every 5 minutes by default, which creates a new 64MB file.
     *
     * The old WAL files are only deleted once no replication slot still references it.
     *
     * Unfortunately, when there are no changes to the db, the database creates new WAL files without the replication slot
     * advancing**.
     *
     * As a workaround, we write a new message every couple of minutes, to make sure that the replication slot advances.
     *
     * **This may be a bug in pgwire or how we're using it.
     */
    keepAlive(): Promise<void>;
    get slotName(): string;
    replicate(): Promise<void>;
    replicateLoop(): Promise<void>;
    replicateOnce(): Promise<void>;
}
