import * as lib_postgres from '@powersync/lib-service-postgres';
import * as service_types from '@powersync/service-types';
import * as t from 'ts-codec';
export declare const validatePort: typeof lib_postgres.validatePort;
export declare const baseUri: typeof lib_postgres.baseUri;
export type NormalizedPostgresConnectionConfig = lib_postgres.NormalizedBasePostgresConnectionConfig;
export declare const POSTGRES_CONNECTION_TYPE: "postgresql";
export declare const PostgresConnectionConfig: t.Intersection<t.Codec<{
    type: string;
    id?: string | undefined;
    tag?: string | undefined;
    debug_api?: boolean | undefined;
} & {
    type: "postgresql";
    id?: string | undefined;
    tag?: string | undefined;
    uri?: string | undefined;
    hostname?: string | undefined;
    port?: number | undefined;
    username?: string | undefined;
    password?: string | undefined;
    database?: string | undefined;
    sslmode?: "verify-full" | "verify-ca" | "disable" | undefined;
    cacert?: string | undefined;
    client_certificate?: string | undefined;
    client_private_key?: string | undefined;
    tls_servername?: string | undefined;
    reject_ip_ranges?: string[] | undefined;
    slot_name_prefix?: string | undefined;
    max_pool_size?: number | undefined;
}, {
    type: string;
    id?: string | undefined;
    tag?: string | undefined;
    debug_api?: boolean | undefined;
} & {
    type: "postgresql";
    id?: string | undefined;
    tag?: string | undefined;
    uri?: string | undefined;
    hostname?: string | undefined;
    port?: string | number | undefined;
    username?: string | undefined;
    password?: string | undefined;
    database?: string | undefined;
    sslmode?: "verify-full" | "verify-ca" | "disable" | undefined;
    cacert?: string | undefined;
    client_certificate?: string | undefined;
    client_private_key?: string | undefined;
    tls_servername?: string | undefined;
    reject_ip_ranges?: string[] | undefined;
    slot_name_prefix?: string | undefined;
    max_pool_size?: number | undefined;
}, string, t.CodecProps>, t.ObjectCodec<{}>>;
/**
 * Config input specified when starting services
 */
export type PostgresConnectionConfig = t.Decoded<typeof PostgresConnectionConfig>;
/**
 * Resolved version of {@link PostgresConnectionConfig}
 */
export type ResolvedConnectionConfig = PostgresConnectionConfig & NormalizedPostgresConnectionConfig;
export declare function isPostgresConfig(config: service_types.configFile.DataSourceConfig): config is PostgresConnectionConfig;
/**
 * Validate and normalize connection options.
 *
 * Returns destructured options.
 */
export declare function normalizeConnectionConfig(options: PostgresConnectionConfig): {
    id: string;
    tag: string;
    hostname: string;
    port: number;
    database: string;
    username: string;
    password: string;
    sslmode: "verify-full" | "verify-ca" | "disable";
    cacert: string | undefined;
    tls_servername: string | undefined;
    lookup: import("net").LookupFunction | undefined;
    client_certificate: string | undefined;
    client_private_key: string | undefined;
    max_pool_size: number;
};
